Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(951)

Unified Diff: chrome/browser/ui/gtk/collected_cookies_gtk.h

Issue 10709006: Show apps protecting local data in chrome://settings/cookies. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: argh Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/gtk/collected_cookies_gtk.h
diff --git a/chrome/browser/ui/gtk/collected_cookies_gtk.h b/chrome/browser/ui/gtk/collected_cookies_gtk.h
index 041419275d2fdc4e6129ef3388fe14716c8e1a83..e0498f84ce53a3038dc6be39dd3e5833a1f1535c 100644
--- a/chrome/browser/ui/gtk/collected_cookies_gtk.h
+++ b/chrome/browser/ui/gtk/collected_cookies_gtk.h
@@ -43,11 +43,11 @@ class CollectedCookiesGtk : public ConstrainedWindowGtkDelegate,
// Initialize all widgets of this dialog.
void Init();
- // True if the selection contains at least one origin node.
- bool SelectionContainsOriginNode(GtkTreeSelection* selection,
- gtk_tree::TreeAdapter* adapter);
+ // True if the selection contains at least one host node.
+ bool SelectionContainsHostNode(GtkTreeSelection* selection,
+ gtk_tree::TreeAdapter* adapter);
- // Enable the allow/block buttons if at least one origin node is selected.
+ // Enable the allow/block buttons if at least one host node is selected.
void EnableControls();
// Add exceptions for all origin nodes within the selection.

Powered by Google App Engine
This is Rietveld 408576698